@@ -2,6 +2,7 @@
 package JMX::Jmx4Perl::Product::Weblogic;
 
 use JMX::Jmx4Perl::Product::BaseHandler;
+use JMX::Jmx4Perl::Request;
 use strict;
 use base "JMX::Jmx4Perl::Product::BaseHandler";
 
@@ -9,11 +10,12 @@ use Carp qw(croak);
 
 =head1 NAME
 
-JMX::Jmx4Perl::Product::Weblogic - Support for Weblogic
+JMX::Jmx4Perl::Product::Weblogic - Handler for Oracle WebLogic
 
 =head1 DESCRIPTION
 
-This is the product handler support for Weblogic 10
+This is the product handler support for Oracle Weblogic Server 9 and 10 
+(L<http://www.oracle.com/appserver/>)
 
 =cut
 
@@ -22,7 +24,7 @@ sub id {
 }
 
 sub name {
-    return "Weblogic";
+    return "Oracle WebLogic Server";
 }
 
 sub order { 
@@ -37,11 +39,16 @@ sub _try_version {
     return $self->try_attribute("version",$self->{server_domain},"ConfigurationVersion");
 }
 
+sub vendor {
+    return "Oracle";
+}
+
 sub server_info { 
     my $self = shift;
     my $ret = $self->SUPER::server_info();
     $ret .= sprintf("%-10.10s %s\n","IP:",$self->{jmx4perl}->get_attribute("SERVER_ADDRESS"));
 }
+
 sub _try_server_domain {
     my $self = shift;
     return $self->try_attribute
@@ -51,7 +58,11 @@ sub _try_server_domain {
 }
 
 sub jsr77 {
-    return 1;
+    return 0;
+}
+
+sub autodetect_pattern {
+    return ("version",1);
 }
 
 sub init_aliases {
@@ -71,12 +82,24 @@ sub init_aliases {
      operations => {
                     # Needs to be done in a more complex. Depends on admin server name *and*
                     # JVM used
-                    THREAD_DUMP => [ "com.bea:Name=examplesServer,ServerRuntime=examplesServer,Type=JRockitRuntime", "ThreadStackDump"]
+                    THREAD_DUMP => \&exec_thread_dump
                    }
      # Alias => [ "mbean", "attribute", "path" ]
     };
 }
 
+sub exec_thread_dump {
+    my $self = shift;
+    my $jmx = $self->{jmx4perl};
+
+    my $beans = $jmx->search("com.bea:Type=JRockitRuntime,*");
+    if ($beans && @{$beans}) {
+        my $bean = $beans->[0];
+        my $request = new JMX::Jmx4Perl::Request(READ,$bean,"ThreadStackDump");
+        return $jmx->request($request);
+    }
+    die $self->name,": Cannot execute THREAD_DUMP because I can't find a suitable JRockitRuntime";
+}
 
 =head1 LICENSE
 
